@@ -83,7 +83,7 @@
 #include "torch-info.h"
 #include "util.h"
 #include "vpn-info.h"
-#include "wifiinfo.h"
+#include "wifi-info.h"
 #include "wwan-info.h"
 #include "wwan/phosh-wwan-ofono.h"
 #include "wwan/phosh-wwan-mm.h"
@@ -284,7 +284,7 @@ on_home_state_changed (PhoshShell *self, GParamSpec *pspec, PhoshHome *home)
 
   priv = phosh_shell_get_instance_private (self);
 
-  g_object_get (priv->home, "state", &state, NULL);
+  state = phosh_home_get_state (PHOSH_HOME (priv->home));
   phosh_shell_set_state (self, PHOSH_STATE_OVERVIEW, state == PHOSH_HOME_STATE_UNFOLDED);
 }
 
@@ -353,13 +353,13 @@ panels_create (PhoshShell *self)
   priv->top_panel = PHOSH_DRAG_SURFACE (phosh_top_panel_new (
                                           phosh_wayland_get_zwlr_layer_shell_v1 (wl),
                                           phosh_wayland_get_zphoc_layer_shell_effects_v1 (wl),
-                                          monitor->wl_output,
+                                          monitor,
                                           top_layer));
   gtk_widget_show (GTK_WIDGET (priv->top_panel));
 
   priv->home = PHOSH_DRAG_SURFACE (phosh_home_new (phosh_wayland_get_zwlr_layer_shell_v1 (wl),
                                                    phosh_wayland_get_zphoc_layer_shell_effects_v1 (wl),
-                                                   monitor->wl_output));
+                                                   monitor));
   gtk_widget_show (GTK_WIDGET (priv->home));
 
   g_signal_connect_swapped (
@@ -780,11 +780,10 @@ setup_idle_cb (PhoshShell *self)
 
   setup_primary_monitor_signal_handlers (self);
 
-  /* Delay signaling the compositor a bit so that idle handlers get a
-   * chance to run and the user has can unlock right away. Ideally
-   * we'd not need this */
+  /* Delay signaling to the compositor a bit so that idle handlers get a chance to run and
+     the user can unlock right away. Ideally we'd not need this */
   priv->startup_finished_id = g_timeout_add_seconds (1, (GSourceFunc)on_startup_finished, self);
-  g_source_set_name_by_id (priv->startup_finished_id, "[phosh] startup finished");
+  g_source_set_name_by_id (priv->startup_finished_id, "[PhoshShell] startup finished");
 
   priv->startup_finished = TRUE;
   g_signal_emit (self, signals[READY], 0);
@@ -950,6 +949,7 @@ phosh_shell_constructed (GObject *object)
 {
   PhoshShell *self = PHOSH_SHELL (object);
   PhoshShellPrivate *priv = phosh_shell_get_instance_private (self);
+  guint id;
 
   G_OBJECT_CLASS (phosh_shell_parent_class)->constructed (object);
 
@@ -1013,7 +1013,8 @@ phosh_shell_constructed (GObject *object)
   priv->feedback_manager = phosh_feedback_manager_new ();
   priv->keyboard_events = phosh_keyboard_events_new ();
 
-  g_idle_add ((GSourceFunc) setup_idle_cb, self);
+  id = g_idle_add ((GSourceFunc) setup_idle_cb, self);
+  g_source_set_name_by_id (id, "[PhoshShell] idle");
 }
 
 /* {{{ Action Map/Group */
@@ -1319,16 +1320,23 @@ phosh_shell_set_primary_monitor (PhoshShell *self, PhoshMonitor *monitor)
    * fallback to enable. Do that in an idle callback so GTK can process
    * pending wayland events for the gone output */
   if (monitor == NULL) {
+    guint id;
     /* No monitor - we're not useful atm */
     notify_compositor_up_state (self, PHOSH_PRIVATE_SHELL_STATE_UNKNOWN);
-    g_idle_add (select_fallback_monitor, self);
+    id = g_idle_add (select_fallback_monitor, self);
+    g_source_set_name_by_id (id, "[PhoshShell] select fallback monitor");
   } else {
     if (needs_notify)
       notify_compositor_up_state (self, PHOSH_PRIVATE_SHELL_STATE_UP);
   }
 }
 
-
+/**
+ * phosh_shell_get_builtin_monitor:
+ * @self: The shell
+ *
+ * Returns:(transfer none)(nullable): the built in monitor or %NULL if there is no built in monitor
+ */
 PhoshMonitor *
 phosh_shell_get_builtin_monitor (PhoshShell *self)
 {
@@ -1346,7 +1354,7 @@ phosh_shell_get_builtin_monitor (PhoshShell *self)
  * phosh_shell_get_primary_monitor:
  * @self: The shell
  *
- * Returns: the primary monitor or %NULL if there currently are no outputs
+ * Returns:(transfer none)(nullable): the primary monitor or %NULL if there currently are no outputs
  */
 PhoshMonitor *
 phosh_shell_get_primary_monitor (PhoshShell *self)
@@ -1850,8 +1858,12 @@ phosh_shell_fade_out (PhoshShell *self, guint timeout)
     fader = phosh_fader_new (monitor);
     g_ptr_array_add (priv->faders, fader);
     gtk_widget_show (GTK_WIDGET (fader));
-    if (timeout > 0)
-      g_timeout_add_seconds (timeout, (GSourceFunc) on_fade_out_timeout, self);
+    if (timeout > 0) {
+      guint id;
+
+      id = g_timeout_add_seconds (timeout, (GSourceFunc) on_fade_out_timeout, self);
+      g_source_set_name_by_id (id, "[PhoshShell] fade out");
+    }
   }
 }
 
